﻿using System;

namespace PdpRtuDownloader.Measurement
{
    /// <summary>
    /// Metadata of a PDP measurement.
    /// </summary>
    public class MeasurementMetadata
    {
        #region Members

        private MeasurementStatus status;
        private int ch1Range;
        private int ch2Range;
        private int ch3Range;
        private int ch4Range;
        private double intTemp1;
        private double extTemp1;
        private double pwr;
        private double batt;
        private double aku;
        private double extTemp2;
        private double humidity1;

        #endregion

        #region Properties

        public MeasurementStatus Status
        {
            get { return status; }
            set { status = value; }
        }

        public int Ch1Range
        {
            get { return ch1Range; }
            set { ch1Range = value; }
        }

        public int Ch2Range
        {
            get { return ch2Range; }
            set { ch2Range = value; }
        }

        public int Ch3Range
        {
            get { return ch3Range; }
            set { ch3Range = value; }
        }

        public int Ch4Range
        {
            get { return ch4Range; }
            set { ch4Range = value; }
        }

        public double IntTemp1
        {
            get { return intTemp1; }
            set { intTemp1 = value; }
        }

        public double ExtTemp1
        {
            get { return extTemp1; }
            set { extTemp1 = value; }
        }

        public double Pwr
        {
            get { return pwr; }
            set { pwr = value; }
        }

        public double Batt
        {
            get { return batt; }
            set { batt = value; }
        }

        public double Aku
        {
            get { return aku; }
            set { aku = value; }
        }

        public double ExtTemp2
        {
            get { return extTemp2; }
            set { extTemp2 = value; }
        }

        public double Humidity1
        {
            get { return humidity1; }
            set { humidity1 = value; }
        }

        #endregion

        #region Constructors

        public MeasurementMetadata()
        {
            SetUndefinedValues();
        }

        #endregion

        #region Methods

        /// <summary>
        /// Sets undefined values to all properties.
        /// </summary>
        public void SetUndefinedValues()
        {
            status = MeasurementStatus.Undefined;
            ch1Range = -1;
            ch2Range = -1;
            ch3Range = -1;
            ch4Range = -1;
            intTemp1 = -100.0;
            extTemp1 = -100.0;
            pwr = -100.0;
            batt = -100.0;
            aku = -100.0;
            extTemp2 = -100.0;
            humidity1 = -100.0;
        }

        public override string ToString()
        {
            return string.Format("[MeasurementMetadata: Status={0}, Ch1Range={1}, Ch2Range={2}, Ch3Range={3}, Ch4Range={4}, IntTemp1={5}, ExtTemp1={6}, Pwr={7}, Batt={8}, Aku={9}, ExtTemp2={10}, Humidity1={11}]",
                Status, Ch1Range, Ch2Range, Ch3Range, Ch4Range, IntTemp1, ExtTemp1, Pwr, Batt, Aku, ExtTemp2, Humidity1);
        }

        #endregion 
    }
}

